Assorted spelling fixes.

Francois Gouget fgouget at free.fr
Thu Jan 18 04:35:50 CST 2007


---
 dlls/comctl32/listview.c       |    4 ++--
 dlls/localspl/tests/localmon.c |    4 ++--
 dlls/mapi32/tests/prop.c       |    4 ++--
 dlls/odbccp32/odbccp32.c       |    2 +-
 dlls/ole32/rpc.c               |    2 +-
 dlls/urlmon/mk.c               |    4 ++--
 dlls/wined3d/state.c           |    6 +++---
 dlls/winspool.drv/info.c       |   10 +++++-----
 include/wine/debug.h           |    2 +-
 tools/winapi/options.pm        |    2 +-
 10 files changed, 20 insertions(+), 20 deletions(-)

diff --git a/dlls/comctl32/listview.c b/dlls/comctl32/listview.c
index bc0db87..53d8837 100644
--- a/dlls/comctl32/listview.c
+++ b/dlls/comctl32/listview.c
@@ -2391,7 +2391,7 @@ static SUBITEM_INFO* LISTVIEW_GetSubItemPtr(HDPA hdpaSubItems, INT nSubItem)
 
 /***
  * DESCRIPTION:
- * Caclulates the desired item width.
+ * Calculates the desired item width.
  *
  * PARAMETER(S):
  * [I] infoPtr : valid pointer to the listview structure
@@ -2436,7 +2436,7 @@ static INT LISTVIEW_CalculateItemWidth(LISTVIEW_INFO *infoPtr)
 
 /***
  * DESCRIPTION:
- * Caclulates the desired item height.
+ * Calculates the desired item height.
  *
  * PARAMETER(S):
  * [I] infoPtr : valid pointer to the listview structure
diff --git a/dlls/localspl/tests/localmon.c b/dlls/localspl/tests/localmon.c
index a254a90..657eba8 100644
--- a/dlls/localspl/tests/localmon.c
+++ b/dlls/localspl/tests/localmon.c
@@ -594,7 +594,7 @@ static void test_XcvDataPort_PortIsValid(void)
         res, GetLastError(), needed);
 
 
-    /* a normal, writeable file is allowed */
+    /* a normal, writable file is allowed */
     needed = (DWORD) 0xdeadbeef;
     SetLastError(0xdeadbeef);
     res = pXcvDataPort(hXcv, cmd_PortIsValidW, (PBYTE) tempfileW, (lstrlenW(tempfileW) + 1) * sizeof(WCHAR), NULL, 0, &needed);
@@ -684,7 +684,7 @@ START_TEST(localmon)
     DWORD   numentries;
     DWORD   res;
 
-    /* This DLL does not exists on Win9x */
+    /* This DLL does not exist on Win9x */
     hdll = LoadLibraryA("localspl.dll");
     if (!hdll) return;
 
diff --git a/dlls/mapi32/tests/prop.c b/dlls/mapi32/tests/prop.c
index 3ffd015..ac397ff 100644
--- a/dlls/mapi32/tests/prop.c
+++ b/dlls/mapi32/tests/prop.c
@@ -1190,7 +1190,7 @@ static void test_IProp(void)
         pMAPIFreeBuffer(lpProps);
     }
 
-    /* Add (NULL) - Can't add NULL's */
+    /* Add (NULL) - Can't add NULLs */
     lpProbs = NULL;
     pvs[0].ulPropTag = PROP_TAG(PT_NULL,0x01);
     sc = IPropData_SetProps(lpIProp, 1, pvs, &lpProbs);
@@ -1198,7 +1198,7 @@ static void test_IProp(void)
        "SetProps(): Expected INVALID_PARAMETER, null, got 0x%08X,%p\n",
        sc, lpProbs);
 
-    /* Add (OBJECT) - Can't add OBJECTS's */
+    /* Add (OBJECT) - Can't add OBJECTs */
     lpProbs = NULL;
     pvs[0].ulPropTag = PROP_TAG(PT_OBJECT,0x01);
     sc = IPropData_SetProps(lpIProp, 1, pvs, &lpProbs);
diff --git a/dlls/odbccp32/odbccp32.c b/dlls/odbccp32/odbccp32.c
index 44957a2..5289e14 100644
--- a/dlls/odbccp32/odbccp32.c
+++ b/dlls/odbccp32/odbccp32.c
@@ -178,7 +178,7 @@ static BOOL SQLInstall_narrow(int mode, LPSTR buffer, LPCWSTR str, WORD str_leng
         }
         else
         {
-            ERR("transfering wide to narrow\n");
+            ERR("transferring wide to narrow\n");
         }
         if (pbuf != buffer)
         {
diff --git a/dlls/ole32/rpc.c b/dlls/ole32/rpc.c
index d28241b..fdb81ed 100644
--- a/dlls/ole32/rpc.c
+++ b/dlls/ole32/rpc.c
@@ -856,7 +856,7 @@ static HRESULT WINAPI ClientRpcChannelBuffer_SendReceive(LPRPCCHANNELBUFFER ifac
     TRACE("hrFault = 0x%08x\n", hrFault);
 
     /* FIXME: this condition should be
-     * "hr == S_OK && (!hrFault || msg->BufferLength > FIELD_OFFSET(ORPCTHAT, extentions) + 4)"
+     * "hr == S_OK && (!hrFault || msg->BufferLength > FIELD_OFFSET(ORPCTHAT, extensions) + 4)"
      * but we don't currently reset the message length for PostMessage
      * dispatched calls */
     if (hr == S_OK && hrFault == S_OK)
diff --git a/dlls/urlmon/mk.c b/dlls/urlmon/mk.c
index 3ee4329..2af01f2 100644
--- a/dlls/urlmon/mk.c
+++ b/dlls/urlmon/mk.c
@@ -256,10 +256,10 @@ static HRESULT WINAPI MkProtocol_Read(IInternetProtocol *iface, void *pv,
 }
 
 static HRESULT WINAPI MkProtocol_Seek(IInternetProtocol *iface, LARGE_INTEGER dlibMove,
-        DWORD dwOrgin, ULARGE_INTEGER *plibNewPosition)
+        DWORD dwOrigin, ULARGE_INTEGER *plibNewPosition)
 {
     MkProtocol *This = PROTOCOL_THIS(iface);
-    FIXME("(%p)->(%d %d %p)\n", This, dlibMove.u.LowPart, dwOrgin, plibNewPosition);
+    FIXME("(%p)->(%d %d %p)\n", This, dlibMove.u.LowPart, dwOrigin, plibNewPosition);
     return E_NOTIMPL;
 }
 
diff --git a/dlls/wined3d/state.c b/dlls/wined3d/state.c
index 8d74006..b17bd9d 100644
--- a/dlls/wined3d/state.c
+++ b/dlls/wined3d/state.c
@@ -816,7 +816,7 @@ static void state_colormat(DWORD state, IWineD3DStateBlockImpl *stateblock) {
     WineDirect3DStridedData *diffuse = &stateblock->wineD3DDevice->strided_streams.u.s.diffuse;
     BOOL isDiffuseSupplied;
 
-    /* Depends on the decoded vertex declaration to read the existance of diffuse data.
+    /* Depends on the decoded vertex declaration to read the existence of diffuse data.
      * The vertex declaration will call this function if the fixed function pipeline is used.
      */
     if(isStateDirty(stateblock->wineD3DDevice, STATE_VDECL)) {
@@ -2640,7 +2640,7 @@ static void vertexdeclaration(DWORD state, IWineD3DStateBlockImpl *stateblock) {
 
     handleStreams(stateblock, useVertexShaderFunction);
 
-    /* Do I have to use ? TRUE : FALSE ? Or can I rely on 15==15 beeing equal to TRUE(=1)? */
+    /* Do I have to use ? TRUE : FALSE ? Or can I rely on 15==15 being equal to TRUE(=1)? */
     transformed = ((device->strided_streams.u.s.position.lpData != NULL ||
                     device->strided_streams.u.s.position.VBO != 0) &&
                     device->strided_streams.u.s.position_transformed) ? TRUE : FALSE;
@@ -2649,7 +2649,7 @@ static void vertexdeclaration(DWORD state, IWineD3DStateBlockImpl *stateblock) {
         updateFog = TRUE;
     }
 
-    /* Reapply lighting if it is not sheduled for reapplication already */
+    /* Reapply lighting if it is not scheduled for reapplication already */
     if(!isStateDirty(device, STATE_RENDER(WINED3DRS_LIGHTING))) {
         state_lighting(STATE_RENDER(WINED3DRS_LIGHTING), stateblock);
     }
diff --git a/include/wine/debug.h b/include/wine/debug.h
index c1ef2b5..31752b0 100644
--- a/include/wine/debug.h
+++ b/include/wine/debug.h
@@ -162,7 +162,7 @@ extern void __wine_dbg_set_functions( const struct __wine_debug_functions *new_f
  * Exported definitions and macros
  */
 
-/* These function return a printable version of a string, including
+/* These functions return a printable version of a string, including
    quotes.  The string will be valid for some time, but not indefinitely
    as strings are re-used.  */
 extern const char *wine_dbgstr_an( const char * s, int n );
diff --git a/tools/winapi/options.pm b/tools/winapi/options.pm
index 714eebb..232de7f 100644
--- a/tools/winapi/options.pm
+++ b/tools/winapi/options.pm
@@ -383,7 +383,7 @@ sub AUTOLOAD {
 
     my $refvalue = $self->{$name};
     if(!defined($refvalue)) {
-	die "<internal>: options.pm: member $name does not exists\n";
+	die "<internal>: options.pm: member $name does not exist\n";
     }
 
     if(ref($$refvalue) ne "HASH") {
diff --git a/dlls/winspool.drv/info.c b/dlls/winspool.drv/info.c
index 3eb382f..66604ff 100644
--- a/dlls/winspool.drv/info.c
+++ b/dlls/winspool.drv/info.c
@@ -1398,8 +1398,8 @@ static LPCWSTR get_basename_from_name(LPCWSTR name)
         /* skip over the servername and search for the following '\'  */
         name = strchrW(&name[2], '\\');
         if ((name) && (name[1])) {
-            /* found a seperator ('\') followed by a name:
-               skip over the seperator and return the rest */
+            /* found a separator ('\') followed by a name:
+               skip over the separator and return the rest */
             name++;
         }
         else
@@ -2319,7 +2319,7 @@ BOOL WINAPI DeleteMonitorW (LPWSTR pName, LPWSTR pEnvironment, LPWSTR pMonitorNa
         return TRUE;
     }
 
-    WARN("monitor %s does not exists\n", debugstr_w(pMonitorName));
+    WARN("monitor %s does not exist\n", debugstr_w(pMonitorName));
     RegCloseKey(hroot);
 
     /* NT: ERROR_UNKNOWN_PRINT_MONITOR (3000), 9x: ERROR_INVALID_PARAMETER (87) */
@@ -5091,7 +5091,7 @@ BOOL WINAPI EnumPortsA( LPSTR pName, DWORD Level, LPBYTE pPorts, DWORD cbBuf,
        We use the smaller Ansi-Size to avoid conflicts with fixed Buffers of old Apps.
      */
     if (res) {
-        /* EnumPortsW collected all Data. Parse them to caclulate ANSI-Size */
+        /* EnumPortsW collected all Data. Parse them to calculate ANSI-Size */
         DWORD   entrysize = 0;
         DWORD   index;
         LPSTR   ptr;
@@ -6469,7 +6469,7 @@ BOOL WINAPI EnumMonitorsA(LPSTR pName, DWORD Level, LPBYTE pMonitors,
        We use the smaller Ansi-Size to avoid conflicts with fixed Buffers of old Apps.
      */
     if (res) {
-        /* EnumMonitorsW collected all Data. Parse them to caclulate ANSI-Size */
+        /* EnumMonitorsW collected all Data. Parse them to calculate ANSI-Size */
         DWORD   entrysize = 0;
         DWORD   index;
         LPSTR   ptr;
-- 
1.4.4.3




More information about the wine-patches mailing list